bayespy.nodes.GaussianGammaISO.get_riemannian_gradient
======================================================

.. currentmodule:: bayespy.nodes

.. automethod:: GaussianGammaISO.get_riemannian_gradient